==> 0.3.5.zip: openhasp/src/lang/nl_NL.h <==
#ifndef HASP_LANG_EN_US_H
#define HASP_LANG_EN_US_H

#define D_USERNAME "Gebruikersnaam:"
#define D_PASSWORD "Wachtwoord:"
#define D_SSID "Ssid:"

#define D_CONFIG_NOT_CHANGED "Instellingen ongewijzigd"
#define D_CONFIG_CHANGED "Instellingen gewijzigd"
#define D_CONFIG_LOADED "Instellingen geladen"

#define D_FILE_LOADING "%s laden..."
#define D_FILE_LOADED "%s geladen"
#define D_FILE_LOAD_FAILED "%s laden mislukt"

#define D_FILE_SAVING "%s bewaren..."
#define D_FILE_SAVED "%s bewaard"
#define D_FILE_SAVE_FAILED "%s bewaren mislukt"

#define D_SERVICE_STARTING "Starten..."
#define D_SERVICE_STARTED "Gestart"
#define D_SERVICE_START_FAILED "Starten mislukt"
#define D_SERVICE_STOPPED "Gestopt"
#define D_SERVICE_DISABLED "Uitgeschakeld"
#define D_SERVICE_CONNECTED "Verbonden"
#define D_SERVICE_DISCONNECTED "Verbroken"

#define D_NETWORK_IP_ADDRESS_RECEIVED "IP adres %s ontvangen"
#define D_NETWORK_ONLINE "online"
#define D_NETWORK_OFFLINE "offline"
#define D_NETWORK_CONNECTION_FAILED "Verbinding mislukt"

#define D_MQTT_DEFAULT_NAME "plaat_%s"
#define D_MQTT_CONNECTING "Verbinden..."
#define D_MQTT_CONNECTED "Verbonden met broker %s als clientID %s"
#define D_MQTT_NOT_CONNECTED "Niet verbonden ???"
#define D_MQTT_DISCONNECTING "Verbinding verbreken..."
#define D_MQTT_DISCONNECTED "Verbinding verbroken"
#define D_MQTT_RECONNECTING "Verbinding verbroken, opnieuw verbinden..."
#define D_MQTT_NOT_CONFIGURED "Broker niet ingesteld"
#define D_MQTT_STARTED "Gestart: %d bytes"
#define D_MQTT_FAILED "Mislukt:"
#define D_MQTT_INVALID_TOPIC "Boodschap met ongeldig onderwerp"
#define D_MQTT_SUBSCRIBED "Ingeschreven op %s"
#define D_MQTT_NOT_SUBSCRIBED "Inschrijving op %s mislukt"
#define D_MQTT_HA_AUTO_DISCOVERY "Registeren HA auto-configuratie"

#define D_TELNET_CLOSING_CONNECTION "Sessie sluiten van %s"
#define D_TELNET_CLIENT_LOGIN_FROM "Client aangemeld van %s"
#define D_TELNET_CLIENT_CONNECT_FROM "Client verbonden van %s"
#define D_TELNET_CLIENT_NOT_CONNECTED "Client NIET vzebonden"
#define D_TELNET_AUTHENTICATION_FAILED "Autorisatie mislukt!"
#define D_TELNET_INCORRECT_LOGIN_ATTEMPT "Aanmelding van %s mislukt"
#define D_TELNET_STARTED "Telnet console gestart"
#define D_TELNET_FAILED "Telnet console starten is mislukt"
#define D_TELNET_CLIENT_CONNECTED "Client verbonden"
#define D_TELNET_CLIENT_NOT_CONNECTED "Client NIET verbonden"
#define D_TELNET_CLIENT_REJECTED "Client geweigerd"

#define D_HASP_INVALID_PAGE "Ongeldige pagina %u"
#define D_HASP_INVALID_LAYER "Kan systeemlaag niet wissen"
#define D_HASP_CHANGE_PAGE "Pagina %u laden"
#define D_HASP_CLEAR_PAGE "Pagina %u wissen"

#define D_OBJECT_DELETED "Object verwijderd"
#define D_OBJECT_UNKNOWN "Onbekend object"
#define D_OBJECT_MISMATCH "Objecten komen niet overeen!"
#define D_OBJECT_LOST "Object kwijt!"
#define D_OBJECT_CREATE_FAILED "Object %u mislukt"
#define D_OBJECT_PAGE_UNKNOWN "Paginga %u niet gedefinieerd"
#define D_OBJECT_EVENT_UNKNOWN "Onbekend Event %d"

#define D_ATTRIBUTE_UNKNOWN "Onbekend attribuut %s"
#define D_ATTRIBUTE_READ_ONLY "%s is alleen-lezen"
#define D_ATTRIBUTE_PAGE_METHOD_INVALID "%s is ongeldig voor een pagina"

#define D_OOBE_SSID_VALIDATED "SSID %s gevalideerd"
#define D_OOBE_AUTO_CALIBRATE "Auto calibratie actief"
#define D_OOBE_CALIBRATED "Reeds gecalibreerd"

#define D_DISPATCH_COMMAND_NOT_FOUND "Opdracht '%s' niet gevonden"
#define D_DISPATCH_INVALID_PAGE "Ongeldige pagina %s"
#define D_DISPATCH_REBOOT "De MCU wordt herstart!"

#define D_JSON_FAILED "JSON verwerking mislukt:"
#define D_JSONL_FAILED "JSONL verwerking mislukt op lijn %d"
#define D_JSONL_SUCCEEDED "Jsonl volledig verwerkt"

#define D_OTA_CHECK_UPDATE "Checking updates URL: %s"
#define D_OTA_CHECK_COMPLETE "Update check complete"
#define D_OTA_CHECK_FAILED "Update check failed: %s"
#define D_OTA_UPDATE_FIRMWARE "OTA Update firmware"
#define D_OTA_UPDATE_COMPLETE "OTA Update complete"
#define D_OTA_UPDATE_APPLY "Applying Firmware & Reboot"
#define D_OTA_UPDATE_FAILED "OTA Update failed"

#define D_HTTP_HASP_DESIGN "HASP Ontwerp"
#define D_HTTP_INFORMATION "Informatie"
#define D_HTTP_HTTP_SETTINGS "HTTP Instellingen"
#define D_HTTP_WIFI_SETTINGS "Wifi Instellingen"
#define D_HTTP_MQTT_SETTINGS "MQTT Instellingen"
#define D_HTTP_GPIO_SETTINGS "GPIO Instellingen"
#define D_HTTP_MDNS_SETTINGS "mDNS Instellingen"
#define D_HTTP_TELNET_SETTINGS "Telnet Instellingen"
#define D_HTTP_DEBUG_SETTINGS "Debug Instellingen"
#define D_HTTP_GUI_SETTINGS "Scherm Instellingen"
#define D_HTTP_SAVE_SETTINGS "Bewaar Instellingen"
#define D_HTTP_UPLOAD_FILE "Bestand Opladen"
#define D_HTTP_ERASE_DEVICE "Alle Instellingen Wissen"
#define D_HTTP_ADD_GPIO "Pin Toevoegen"
#define D_HTTP_BACK "Terug"
#define D_HTTP_REFRESH "Vernieuwen"
#define D_HTTP_PREV_PAGE "Vorige Pagina"
#define D_HTTP_NEXT_PAGE "Volgende Pagina"
#define D_HTTP_CALIBRATE "Calibratie"
#define D_HTTP_SCREENSHOT "Schermafbeelding"
#define D_HTTP_FILE_BROWSER "Bestandsverkenner"
#define D_HTTP_FIRMWARE_UPGRADE "Firmware Upgrade"
#define D_HTTP_UPDATE_FIRMWARE "Firmware Bijwerken"
#define D_HTTP_FACTORY_RESET "Fabrieksinstellingen"
#define D_HTTP_MAIN_MENU "Hoofdmenu"
#define D_HTTP_REBOOT "Herstarten"
#define D_HTTP_CONFIGURATION "Configuratie"

#define D_OOBE_MSB "Raak het scherm aan om WiFi in te stellen of meld je aan op AP:"
#define D_OOBE_SCAN_TO_CONNECT "Scan code"

#endif

==> 0.5.2.zip: openhasp/src/lang/nl_NL.h <==
#ifndef HASP_LANG_EN_US_H
#define HASP_LANG_EN_US_H

#define D_USERNAME "Gebruikersnaam:"
#define D_PASSWORD "Wachtwoord:"
#define D_SSID "Ssid:"

#define D_ERROR_OUT_OF_MEMORY "Geen geheugen bechikbaar"
#define D_ERROR_UNKNOWN "Onbekende fout"

#define D_CONFIG_NOT_CHANGED "Instellingen ongewijzigd"
#define D_CONFIG_CHANGED "Instellingen gewijzigd"
#define D_CONFIG_LOADED "Instellingen geladen"

#define D_FILE_LOADING "%s laden..."
#define D_FILE_LOADED "%s geladen"
#define D_FILE_LOAD_FAILED "%s laden mislukt"

#define D_FILE_SAVING "%s bewaren..."
#define D_FILE_SAVED "%s bewaard"
#define D_FILE_SAVE_FAILED "%s bewaren mislukt"

#define D_SERVICE_STARTING "Starten..."
#define D_SERVICE_STARTED "Gestart"
#define D_SERVICE_START_FAILED "Starten mislukt"
#define D_SERVICE_STOPPED "Gestopt"
#define D_SERVICE_DISABLED "Uitgeschakeld"
#define D_SERVICE_CONNECTED "Verbonden"
#define D_SERVICE_DISCONNECTED "Verbroken"

#define D_NETWORK_IP_ADDRESS_RECEIVED "IP adres %s ontvangen"
#define D_NETWORK_ONLINE "online"
#define D_NETWORK_OFFLINE "offline"
#define D_NETWORK_CONNECTION_FAILED "Verbinding mislukt"

#define D_MQTT_DEFAULT_NAME "plaat_%s"
#define D_MQTT_CONNECTING "Verbinden..."
#define D_MQTT_CONNECTED "Verbonden met broker %s als clientID %s"
#define D_MQTT_NOT_CONNECTED "Niet verbonden ???"
#define D_MQTT_DISCONNECTING "Verbinding verbreken..."
#define D_MQTT_DISCONNECTED "Verbinding verbroken"
#define D_MQTT_RECONNECTING "Verbinding verbroken, opnieuw verbinden..."
#define D_MQTT_NOT_CONFIGURED "Broker niet ingesteld"
#define D_MQTT_STARTED "Gestart: %d bytes"
#define D_MQTT_FAILED "Mislukt:"
#define D_MQTT_INVALID_TOPIC "Boodschap met ongeldig onderwerp"
#define D_MQTT_SUBSCRIBED "Ingeschreven op %s"
#define D_MQTT_NOT_SUBSCRIBED "Inschrijving op %s mislukt"
#define D_MQTT_HA_AUTO_DISCOVERY "Registeren HA auto-configuratie"
#define D_MQTT_PAYLOAD_TOO_LONG "Payload is te lang (%d bytes)"

#define D_TELNET_CLOSING_CONNECTION "Sessie sluiten van %s"
#define D_TELNET_CLIENT_LOGIN_FROM "Client aangemeld van %s"
#define D_TELNET_CLIENT_CONNECT_FROM "Client verbonden van %s"
#define D_TELNET_AUTHENTICATION_FAILED "Autorisatie mislukt!"
#define D_TELNET_INCORRECT_LOGIN_ATTEMPT "Aanmelding van %s mislukt"
#define D_TELNET_STARTED "Telnet console gestart"
#define D_TELNET_FAILED "Telnet console starten is mislukt"
#define D_TELNET_CLIENT_CONNECTED "Client verbonden"
#define D_TELNET_CLIENT_NOT_CONNECTED "Client NIET verbonden"
#define D_TELNET_CLIENT_REJECTED "Client geweigerd"

#define D_HASP_INVALID_PAGE "Ongeldige pagina %u"
#define D_HASP_INVALID_LAYER "Kan systeemlaag niet wissen"
#define D_HASP_CHANGE_PAGE "Pagina %u laden"
#define D_HASP_CLEAR_PAGE "Pagina %u wissen"

#define D_OBJECT_DELETED "Object verwijderd"
#define D_OBJECT_UNKNOWN "Onbekend object"
#define D_OBJECT_MISMATCH "Objecten komen niet overeen!"
#define D_OBJECT_LOST "Object kwijt!"
#define D_OBJECT_CREATE_FAILED "Object %u mislukt"
#define D_OBJECT_PAGE_UNKNOWN "Paginga %u niet gedefinieerd"
#define D_OBJECT_EVENT_UNKNOWN "Onbekend Event %d"

#define D_ATTRIBUTE_UNKNOWN "Onbekend attribuut %s"
#define D_ATTRIBUTE_READ_ONLY "%s is alleen-lezen"
#define D_ATTRIBUTE_PAGE_METHOD_INVALID "%s is ongeldig voor een pagina"

#define D_OOBE_SSID_VALIDATED "SSID %s gevalideerd"
#define D_OOBE_AUTO_CALIBRATE "Auto calibratie actief"
#define D_OOBE_CALIBRATED "Reeds gecalibreerd"

#define D_DISPATCH_COMMAND_NOT_FOUND "Opdracht '%s' niet gevonden"
#define D_DISPATCH_INVALID_PAGE "Ongeldige pagina %s"
#define D_DISPATCH_REBOOT "De MCU wordt herstart!"

#define D_JSON_FAILED "JSON verwerking mislukt:"
#define D_JSONL_FAILED "JSONL verwerking mislukt op lijn %d"
#define D_JSONL_SUCCEEDED "Jsonl volledig verwerkt"

#define D_OTA_CHECK_UPDATE "Controle update URL: %s"
#define D_OTA_CHECK_COMPLETE "Update controle klaar"
#define D_OTA_CHECK_FAILED "Update check failed: %s"
#define D_OTA_UPDATE_FIRMWARE "OTA Firmware bijwerken"
#define D_OTA_UPDATE_COMPLETE "OTA Firmware bijgewerkt"
#define D_OTA_UPDATE_APPLY "Firmware Schrijven & Herstart"
#define D_OTA_UPDATE_FAILED "OTA Update mislukt"

#define D_HTTP_HASP_DESIGN "HASP Ontwerp"
#define D_HTTP_INFORMATION "Informatie"
#define D_HTTP_HTTP_SETTINGS "HTTP Instellingen"
#define D_HTTP_WIFI_SETTINGS "Wifi Instellingen"
#define D_HTTP_MQTT_SETTINGS "MQTT Instellingen"
#define D_HTTP_GPIO_SETTINGS "GPIO Instellingen"
#define D_HTTP_MDNS_SETTINGS "mDNS Instellingen"
#define D_HTTP_TELNET_SETTINGS "Telnet Instellingen"
#define D_HTTP_DEBUG_SETTINGS "Debug Instellingen"
#define D_HTTP_GUI_SETTINGS "Scherm Instellingen"
#define D_HTTP_SAVE_SETTINGS "Bewaar Instellingen"
#define D_HTTP_UPLOAD_FILE "Bestand Opladen"
#define D_HTTP_ERASE_DEVICE "Alle Instellingen Wissen"
#define D_HTTP_ADD_GPIO "Pin Toevoegen"
#define D_HTTP_BACK "Terug"
#define D_HTTP_REFRESH "Vernieuwen"
#define D_HTTP_PREV_PAGE "Vorige Pagina"
#define D_HTTP_NEXT_PAGE "Volgende Pagina"
#define D_HTTP_CALIBRATE "Calibratie"
#define D_HTTP_SCREENSHOT "Schermafbeelding"
#define D_HTTP_FILE_BROWSER "Bestandsverkenner"
#define D_HTTP_FIRMWARE_UPGRADE "Firmware Upgrade"
#define D_HTTP_UPDATE_FIRMWARE "Firmware Bijwerken"
#define D_HTTP_FACTORY_RESET "Fabrieksinstellingen"
#define D_HTTP_MAIN_MENU "Hoofdmenu"
#define D_HTTP_REBOOT "Herstarten"
#define D_HTTP_CONFIGURATION "Configuratie"

#define D_OOBE_MSG "Raak het scherm aan om WiFi in te stellen of meld je aan op AP:"
#define D_OOBE_SCAN_TO_CONNECT "Scan code"

#define D_WIFI_CONNECTING_TO "Verbinden met %s"
#define D_WIFI_CONNECTED_TO "Verbonden met %s, IP aanvragen..."

#endif
